Struct TimePositionVelocity
pub struct TimePositionVelocity {Show 46 fields
pub device: Option<String>,
pub mode: NmeaMode,
pub alt_hae: Option<f32>,
pub alt_msl: Option<f32>,
pub ant: Option<ExternalAntennaStatus>,
pub climb: Option<f32>,
pub clock_bias: Option<f32>,
pub clock_drift: Option<f32>,
pub datum: Option<String>,
pub depth: Option<f32>,
pub dgps_age: Option<Duration>,
pub dgps_sta: Option<f32>,
pub ecef: Option<Box<Ecef>>,
pub epc: Option<f32>,
pub epd: Option<f32>,
pub eph: Option<f32>,
pub eps: Option<f32>,
pub ept: Option<f32>,
pub epx: Option<f32>,
pub epy: Option<f32>,
pub epv: Option<f32>,
pub geoid_sep: Option<f32>,
pub jam: Option<i32>,
pub lat: Option<f64>,
pub leap_seconds: Option<u32>,
pub lon: Option<f64>,
pub mag_track: Option<f32>,
pub mag_var: Option<f32>,
pub rel_down: Option<f32>,
pub rel_east: Option<f32>,
pub rel_north: Option<f32>,
pub sep: Option<f32>,
pub speed: Option<f32>,
pub status: Option<FixStatus>,
pub temp: Option<f32>,
pub time: Option<DateTime<Utc>>,
pub track: Option<f32>,
pub vel_down: Option<f32>,
pub vel_east: Option<f32>,
pub vel_north: Option<f32>,
pub wind_angle_mag: Option<f32>,
pub rel_wind_angle: Option<f32>,
pub true_wind_angle: Option<f32>,
pub rel_wind_speed: Option<f32>,
pub true_wind_speed: Option<f32>,
pub water_temp: Option<f32>,
}Expand description
Time-position-velocity report.
Fields
device: Option<String>Name of the originating device.
mode: NmeaModeNMEA mode.
alt_hae: Option<f32>Altitude, height above ellipsoid, in meters. Probably WGS84.
alt_msl: Option<f32>MSL Altitude in meters.
The geoid used is rarely specified and is often inaccurate. See the comments below on geoidSep. altMSL is altHAE minus geoidSep.
ant: Option<ExternalAntennaStatus>External Antenna Status.
climb: Option<f32>Climb (positive) or sink (negative) rate, meters per second.
clock_bias: Option<f32>Offset of local GNSS clock relative to UTC, in ns. AKA Clock Offset.
Sometimes given as Part Per Billion (ppb) which is the same as ns.
clock_drift: Option<f32>The rate at which the local clock is drifting. In ns/s.
datum: Option<String>Current datum. Hopefully WGS84.
depth: Option<f32>Depth in meters. Probably depth below the keel…
dgps_age: Option<Duration>Age of DGPS data. In seconds
dgps_sta: Option<f32>Station of DGPS data.
ecef: Option<Box<Ecef>>Earth-centered, Earth-fixed coordinate system.
epc: Option<f32>Estimated climb error in meters per second. Certainty unknown.
epd: Option<f32>Estimated track (direction) error in degrees. Certainty unknown.
eph: Option<f32>Estimated horizontal Position (2D) Error in meters.
Also known as Estimated Position Error (epe). Certainty unknown.
eps: Option<f32>Estimated speed error in meters per second. Certainty unknown.
ept: Option<f32>Estimated time stamp error in seconds. Certainty unknown.
epx: Option<f32>Longitude error estimate in meters. Certainty unknown.
epy: Option<f32>Latitude error estimate in meters. Certainty unknown.
epv: Option<f32>Estimated vertical error in meters. Certainty unknown.
geoid_sep: Option<f32>Geoid separation is the difference between the WGS84 reference ellipsoid and the geoid (Mean Sea Level) in meters.
Almost no GNSS receiver specifies how they compute their geoid. gpsd interpolates the geoid from a 5x5 degree table of EGM2008 values when the receiver does not supply a geoid separation. The gpsd computed geoidSep is usually within one meter of the “true” value, but can be off as much as 12 meters.
jam: Option<i32>Jamming Indicator.
0 (no jamming) to 255 (severe jamming). -1 means unset.
lat: Option<f64>Latitude in degrees: +/- signifies North/South.
leap_seconds: Option<u32>Current leap seconds.
lon: Option<f64>Longitude in degrees: +/- signifies East/West.
mag_track: Option<f32>Course over ground, degrees magnetic.
mag_var: Option<f32>Magnetic variation, degrees.
Also known as the magnetic declination (the direction of the horizontal component of the magnetic field measured clockwise from north) in degrees, Positive is West variation. Negative is East variation.
rel_down: Option<f32>Down component of relative position vector in meters.
rel_east: Option<f32>East component of relative position vector in meters.
rel_north: Option<f32>North component of relative position vector in meters.
sep: Option<f32>Estimated Spherical (3D) Position Error in meters.
Guessed to be 95% confidence, but many GNSS receivers do not specify, so certainty unknown.
speed: Option<f32>Speed over ground, meters per second.
status: Option<FixStatus>GPS fix status.
temp: Option<f32>Receiver temperature in degrees Celsius.
time: Option<DateTime<Utc>>Time/date stamp in ISO8601 format, UTC.
May have a fractional part of up to .001sec precision. May be absent if the mode is not 2D or 3D. May be present, but invalid, if there is no fix. Verify 3 consecutive 3D fixes before believing it is UTC. Even then it may be off by several seconds until the current leap seconds is known.
track: Option<f32>Course over ground, degrees from true north.
vel_down: Option<f32>Down velocity component in meters.
vel_east: Option<f32>East velocity component in meters.
vel_north: Option<f32>North velocity component in meters.
wind_angle_mag: Option<f32>Wind angle magnetic in degrees.
rel_wind_angle: Option<f32>Wind angle relative in degrees.
true_wind_angle: Option<f32>Wind angle true in degrees.
rel_wind_speed: Option<f32>Wind speed relative in meters per second.
true_wind_speed: Option<f32>Wind speed true in meters per second.
water_temp: Option<f32>Water temperature in degrees Celsius.